@@ -114,8 +114,10 @@ class Baseline(Model):
         self.f1 = Dense(64, activation='relu')
         self.d2 = Dropout(0.2)
         self.f2 = Dense(2, activation='softmax')
-
+    
+    
     def call(self, x):
+        
         x = self.c1(x)
         x = self.b1(x)
         x = self.a1(x)
@@ -164,6 +166,7 @@ def readBmp(files,imgw=None,imgh=None,imgf=None):
         
     return image_group
 
+
 def get_train_batch(X_train, y_train, batch_size, img_w, img_h,img_f,endless = True):
     '''
     参数：
@@ -284,7 +287,7 @@ def train(tag = None):
     
     
     model = Baseline()
-    checkpoint_save_path = os.path.join(modelpath,tag,"ckpt","save.ckpt")
+    checkpoint_save_path = os.path.join(modelpath,tag,"ckpt")
     log_dir = os.path.join(modelpath,tag,"logs/")
     
     if os.path.exists(checkpoint_save_path + '.index'):
@@ -335,7 +338,7 @@ def predictDirectory(dirtag,modeltag):
         return "error:dirtag [{}] is not exists".format(dirtag)
     
     if modeltag:
-        checkpoint_path = os.path.join(modelpath,modeltag,"ckpt","save.ckpt")
+        checkpoint_path = os.path.join(modelpath,modeltag,"ckpt")
         if os.path.exists(checkpoint_path + '.index'):
             print('-------------load the model-----------------')
             model.load_weights(checkpoint_path)
@@ -369,8 +372,8 @@ def predictSingle(imagepath,modeltag = None,classify = None):
         #model = Baseline()
         
         if modeltag:
-            checkpoint_path = os.path.join(modelpath,modeltag,"ckpt","save.ckpt")
-            if os.path.exists(checkpoint_path + '.index'):
+            checkpoint_path = os.path.join(modelpath,modeltag,"ckpt")
+            if os.path.exists(checkpoint_path+".index"):
                 print('-------------load the model-----------------')
                 model.load_weights(checkpoint_path)
                 classify = getClassify(modeltag)
@@ -398,14 +401,16 @@ def predictSingle(imagepath,modeltag = None,classify = None):
         
         result = "name:{},maybe:{},percent:{}%,spend:{}s".format(imagename,maybetype,round(100.0*percent,2),round(e-s,2))
         #result = "maybe:{},{},{}".format(maybe,round(percent,2),round(e-s,2))
+        
         result = {
             "name":imagename,
             "maybetype":maybetype,
-            "percent":round(percent,2),
-            "spend":round(e-s,2)
+            "percent":str(round(percent,2)),
+            "spend":str(round(e-s,2))
             }
         return result
     except Exception as err:
+        
         return {"error":str(err)}
 
 def predictPicture(imagepath,ckptpath = None):
@@ -416,7 +421,7 @@ def predictPicture(imagepath,ckptpath = None):
         
         
         if ckptpath:
-            checkpoint_path = os.path.join(ckptpath,"save.ckpt")
+            checkpoint_path = os.path.join(modelpath,modeltag,"ckpt")
             if os.path.exists(checkpoint_path + '.index'):
                 print('-------------load the model-----------------')
                 model.load_weights(checkpoint_path)
